# IODetected


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**detection_entries** | [**List[ToolDetectionEntry]**](ToolDetectionEntry.md) |  | [optional] 

## Example

```python
from aisecurity.generated_openapi_client.models.io_detected import IODetected

# TODO update the JSON string below
json = "{}"
# create an instance of IODetected from a JSON string
io_detected_instance = IODetected.from_json(json)
# print the JSON string representation of the object
print(IODetected.to_json())

# convert the object into a dict
io_detected_dict = io_detected_instance.to_dict()
# create an instance of IODetected from a dict
io_detected_from_dict = IODetected.from_dict(io_detected_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


